# -*- coding: UTF-8 -*-
strings = {
        u"P1AA01" : u"La Cabane des Robinson",
        u"P1AA02" : u"Indiana Jones and the Temple of Peril",
        u"P1AA04" : u"Pirates of the Caribbean",
        u"P1DA03" : u"Autopia",
        u"P1DA04" : u"Buzz Lightyear Laser Blast",
        u"P1DA06" : u"Les Mystères du Nautilus",
        u"P1DA07" : u"Orbitron",
        u"P1DA08" : u"Space Mountain: Mission 2",
        u"P1DA09" : u"Star Tours",
        u"P1DA12" : u"Captain EO",
        u"P1NA00" : u"Alice's Curious Labyrinth",
        u"P1NA01" : u"Blanche-Neige et les Sept Nains",
        u"P1NA02" : u"Le Carrousel de Lancelot",
        u"P1NA03" : u"Casey Jr. - le Petit Train du Cirque",
        u"P1NA05" : u"Dumbo the Flying Elephant",
        u"P1NA07" : u"\"it's a small world\" Celebration",
        u"P1NA08" : u"Mad Hatter's Tea Cups",
        u"P1NA09" : u"Le Pays des Contes de Fées",
        u"P1NA10" : u"Peter Pan's Flight",
        u"P1NA13" : u"Les Voyages de Pinocchio",
        u"P1RA00" : u"Big Thunder Mountain",
        u"P1RA03" : u"Phantom Manor",
        u"P1RA04" : u"River Rogue Keelboats",
        u"P2XA00" : u"Studio Tram Tour: Behind the Magic",
        u"P2XA01" : u"CinéMagique",
        u"P2XA02" : u"Cars Quatre Roues Rallye",
        u"P2XA03" : u"Crush's Coaster",
        u"P2XA05" : u"Flying Carpets Over Agrabah",
        u"P2XA06" : u"RC Racer",
        u"P2XA07" : u"Toy Soldiers Parachute Drop",
        u"P2XA08" : u"Slinky Dog Zigzag Spin",
        u"P2ZA00" : u"Armageddon : les Effets Spéciaux",
        u"P2ZA01" : u"Rock 'n' Roller Coaster starring Aerosmith",
        u"P2ZA02" : u"The Twilight Zone Tower of Terror",
        u"P2XA09" : u"Ratatouille : L'Aventure Totalement Toquée de Rémy"
}
